==> hubzero-cms-2.1.0_2.1.14.9-1+deb8.tar.gz: source/cms/README.md <==
# The HUBzero® Platform for Scientific Collaboration
[![Build Status](https://travis-ci.org/hubzero/hubzero-cms.svg?branch=2.1.0)](https://travis-ci.org/hubzero/hubzero-cms)

## What is HUBzero?

HUBzero is an open source software platform for building powerful Web sites that support scientific discovery, learning, and collaboration. Some refer to such web sites as "collaboratories" supporting "team science." We call them "hubs" because each site becomes a focal point for its user community. The HUBzero platform now supports dozens of hubs across a variety of disciplines, including cancer research, pharmaceuticals, biofuels, microelectromechanical systems, climate modeling, water quality, volcanology, and more.

For more information about HUBzero, visit https://hubzero.org.

## Installation

### Virtual Machine

Preconfigured virtual machine images that contain the full version of the HUBzero platform can be found at http://hubzero.org/download. See the Quick Start file inside the package for a step-by-step method to get the virtual machine up and running.

### Packages

Instructions for installing the HUBzero platform from packages can be found at http://help.hubzero.org/documentation/current/installation.

## Documentation

Both user and developer documentation for the CMS can be found at https://help.hubzero.org/documentation/current.

## Contributing

HUBzero is an open source project, with code contributions from nuermous groups and organizations. If you'd like to contribute, please read the Contribution Guidelines found at https://help.hubzero.org/documentation/current/webdevs/index/contributions.

## Issues

Please report any bugs or issues at https://help.hubzero.org/support.

## Roadmap

Checkout what is on our development roadmap at https://hubzero.org/roadmap.

==> hubzero-cms-2.2.0_2.2.6.0-1+deb8.tar.gz: source/cms/README.md <==
# The HUBzero® Platform for Scientific Collaboration
[![Build Status](https://travis-ci.org/hubzero/hubzero-cms.svg?branch=master)](https://travis-ci.org/hubzero/hubzero-cms)

## What is HUBzero?

HUBzero is an open source software platform for building powerful Web sites that support scientific discovery, learning, and collaboration. Some refer to such web sites as "collaboratories" supporting "team science." We call them "hubs" because each site becomes a focal point for its user community. The HUBzero platform now supports dozens of hubs across a variety of disciplines, including cancer research, pharmaceuticals, biofuels, microelectromechanical systems, climate modeling, water quality, volcanology, and more.

For more information about HUBzero, visit https://hubzero.org.

## Installation

### Virtual Machine

Preconfigured virtual machine images that contain the full version of the HUBzero platform can be found at http://hubzero.org/download. See the Quick Start file inside the package for a step-by-step method to get the virtual machine up and running.

### Packages

Instructions for installing the HUBzero platform from packages can be found at http://help.hubzero.org/documentation/current/installation.

## Documentation

Both user and developer documentation for the CMS can be found at https://help.hubzero.org/documentation/current.

## Contributing

HUBzero is an open source project, with code contributions from numerous groups and organizations. If you'd like to contribute, please read the Contribution Guidelines found at https://help.hubzero.org/documentation/current/webdevs/index/contributions.

## Issues

Please report any bugs or issues at https://help.hubzero.org/support.

## Roadmap

Checkout what is on our development roadmap at https://help.hubzero.org/documentation/roadmap.
